@@ -1,13 +1,9 @@
-import sys
-
-import objc
-
-import Quartz
-import LaunchServices
-
-import Utilities
-import DrawingBasics
 import AppDrawing
+import DrawingBasics
+import LaunchServices
+import objc
+import Quartz
+import Utilities
 
 # import Carbon.QT
 
@@ -24,7 +20,9 @@ def COMPUTE_BEST_BYTES_PER_ROW(bpr):
 _rasterDataForContext = {}
 
 
-def createRGBBitmapContext(width, height, wantDisplayColorSpace, needsTransparentBitmap):
+def createRGBBitmapContext(
+    width, height, wantDisplayColorSpace, needsTransparentBitmap
+):
     # This routine allocates data for a pixel array that contains width*height
     # pixels where each pixel is 4 bytes. The format is 8-bit ARGB or XRGB, depending on
     # whether needsTransparentBitmap is true. In order to get the recommended
@@ -76,7 +74,9 @@ def createRGBBitmapContext(width, height, wantDisplayColorSpace, needsTransparen
         # Since the drawing destination is opaque, first paint
         # the context bits to white.
         Quartz.CGContextSaveGState(context)
-        Quartz.CGContextSetFillColorWithColor(context, Utilities.getRGBOpaqueWhiteColor())
+        Quartz.CGContextSetFillColorWithColor(
+            context, Utilities.getRGBOpaqueWhiteColor()
+        )
         Quartz.CGContextFillRect(context, Quartz.CGRectMake(0, 0, width, height))
         Quartz.CGContextRestoreGState(context)
 
@@ -106,7 +106,7 @@ def createImageFromBitmapContext(c):
     ) * Quartz.CGBitmapContextGetHeight(c)
 
     if rasterData is None:
-        fprintf(stderr, "Context is not a bitmap context!")
+        print("Context is not a bitmap context!")
 
     # Create the data provider from the image data
     dataProvider = Quartz.CGDataProviderCreateWithData(
@@ -147,6 +147,7 @@ def exportCGImageToFileWithQT(image, url, outputFormat, dpi):
     through MacPython. The code below is mostly there in case someone fixes
     the MacPython QuickTime bindings.
     """
+    # XXX: Finish
     return
 
     if outputFormat.lower() == LaunchServices.kUTTypeTIFF.lower():
@@ -162,27 +163,35 @@ def exportCGImageToFileWithQT(image, url, outputFormat, dpi):
         print("Requested image export format %@s unsupported" % (outputFormat,))
         return
 
-        result, dataRef, dataRefType = QTNewDataReferenceFromCFURL(url, 0, None, None)
+        result, dataRef, dataRefType = Quartz.QTNewDataReferenceFromCFURL(
+            url, 0, None, None
+        )
         if result == 0:
-            result, graphicsExporter = OpenADefaultComponent(
-                GraphicsExporterComponentType, imageExportType, graphicsExporter
+            result, graphicsExporter = Quartz.OpenADefaultComponent(
+                Quartz.GraphicsExporterComponentType,
+                imageExportType,
+                graphicsExporter,  # noqa: F821
             )
             if result == 0:
-                result = GraphicsExportSetInputCGImage(graphicsExporter, image)
+                result = Quartz.GraphicsExportSetInputCGImage(graphicsExporter, image)
                 if result == 0:
-                    result = GraphicsExportSetResolution(
-                        graphicsExporter, FloatToFixed(dpi), FloatToFixed(dpi)
+                    result = Quartz.GraphicsExportSetResolution(
+                        graphicsExporter,
+                        Quartz.FloatToFixed(dpi),
+                        Quartz.FloatToFixed(dpi),
                     )
                 if result == 0:
-                    result = GraphicsExportSetOutputDataReference(
+                    result = Quartz.GraphicsExportSetOutputDataReference(
                         graphicsExporter, dataRef, dataRefType
                     )
                 if result == 0:
-                    result, sizeWritten = GraphicsExportDoExport(graphicsExporter, None)
-                CloseComponent(graphicsExporter)
+                    result, sizeWritten = Quartz.GraphicsExportDoExport(
+                        graphicsExporter, None
+                    )
+                Quartz.CloseComponent(graphicsExporter)
 
         if dataRef:
-            DisposeHandle(dataRef)
+            Quartz.DisposeHandle(dataRef)
 
         if result:
             print("QT export got bad result = %d!" % (result,))
@@ -192,7 +201,9 @@ def exportCGImageToFileWithDestination(image, url, outputFormat, dpi):
     # Create an image destination at the supplied URL that
     # corresponds to the output image format. The destination will
     # only contain 1 image.
-    imageDestination = Quartz.CGImageDestinationCreateWithURL(url, outputFormat, 1, None)
+    imageDestination = Quartz.CGImageDestinationCreateWithURL(
+        url, outputFormat, 1, None
+    )
 
     if imageDestination is None:
         print("Couldn't create image destination!")
@@ -225,11 +236,13 @@ def MakeImageDocument(url, imageType, exportInfo):
     # Create an RGB Bitmap context using the generic calibrated RGB color space
     # instead of the display color space.
     useDisplayColorSpace = False
-    c = createRGBBitmapContext(width, height, useDisplayColorSpace, needTransparentBitmap)
+    c = createRGBBitmapContext(
+        width, height, useDisplayColorSpace, needTransparentBitmap
+    )
 
     if c is None:
         print("Couldn't make destination bitmap context")
-        return memFullErr
+        return -1
 
     # Scale the coordinate system based on the resolution in dots per inch.
     Quartz.CGContextScaleCTM(c, dpi / 72, dpi / 72)
@@ -262,7 +275,7 @@ def MakeImageDocument(url, imageType, exportInfo):
 
     if image is None:
         # Users of this code should update this to be an error code they find useful.
-        return memFullErr
+        return -1
 
     # Now export the image.
     if exportInfo.useQTForExport:
@@ -335,7 +348,7 @@ def doSimpleCGLayer(context):
         # Paint 4 columns of layer objects, moving
         # across the drawing canvas by skipping a
         # square on the grid each time across.
-        for i in range(4):
+        for _ in range(4):
             # Draw the layer at the current origin.
             Quartz.CGContextDrawLayerAtPoint(context, Quartz.CGPointZero, layer)
             # Translate across two layer widths.
@@ -465,7 +478,9 @@ def doAlphaOnlyContext(context):
         return
 
     # Set the fill color space.
-    Quartz.CGContextSetFillColorSpace(context, Utilities.getTheCalibratedRGBColorSpace())
+    Quartz.CGContextSetFillColorSpace(
+        context, Utilities.getTheCalibratedRGBColorSpace()
+    )
     opaqueBlue = (0.11, 0.208, 0.451, 1.0)
     # Set the painting color to opaque blue.
     Quartz.CGContextSetFillColor(context, opaqueBlue)
@@ -621,7 +636,7 @@ def createLayerWithImageForContext(c, url):
     # Create the layer to draw into.
     layer = Quartz.CGLayerCreateWithContext(c, layerSize, None)
     if layer is None:
-        return NULL
+        return None
 
     # Get the context corresponding to the layer. Note
     # that this is a 'Get' function so the code must
