@@ -1,9 +1,9 @@
-from PyObjCTools.TestSupport import *
-from Quartz.QuartzCore import *
-import os
+from PyObjCTools.TestSupport import TestCase, min_os_level
+import objc
+import Quartz
 
 
-class TestCIImageProviderHelper(NSObject):
+class TestCIImageProviderHelper(Quartz.NSObject):
     @objc.namedSelector(b"provideImageData:bytesPerRow:origin::size::userInfo:")
     def provideImageData_bytesPerRow_origin__size__userInfo_(
         self, data, rowbytes, x, y, width, height, userInfo
@@ -55,13 +55,9 @@ class TestCIImageProvider(TestCase):
         )
 
     def testConstants(self):
-        self.assertIsInstance(kCIImageProviderTileSize, unicode)
-        self.assertIsInstance(kCIImageProviderUserInfo, unicode)
+        self.assertIsInstance(Quartz.kCIImageProviderTileSize, str)
+        self.assertIsInstance(Quartz.kCIImageProviderUserInfo, str)
 
     @min_os_level("10.6")
     def testConstants10_6(self):
-        self.assertIsInstance(kCIOutputNativeSizeKey, unicode)
-
-
-if __name__ == "__main__":
-    main()
+        self.assertIsInstance(Quartz.kCIOutputNativeSizeKey, str)
