@@ -1,8 +1,9 @@
-from PyObjCTools.TestSupport import *
-from Quartz import *
+from PyObjCTools.TestSupport import TestCase, min_os_level
+import Quartz
+import objc
 
 
-class TestIKSlideShowHelper(NSObject):
+class TestIKSlideShowHelper(Quartz.NSObject):
     def numberOfSlideshowItems(self):
         return 1
 
@@ -51,35 +52,31 @@ class TestIKSlideshow(TestCase):
 
     @min_os_level("10.5")
     def testMethods(self):
-        self.assertResultIsBOOL(IKSlideshow.canExportToApplication_)
+        self.assertResultIsBOOL(Quartz.IKSlideshow.canExportToApplication_)
 
     @min_os_level("10.5")
     def testConstants(self):
-        self.assertIsInstance(IKSlideshowModeImages, unicode)
-        self.assertIsInstance(IKSlideshowModePDF, unicode)
-        self.assertIsInstance(IKSlideshowModeOther, unicode)
-        self.assertIsInstance(IKSlideshowWrapAround, unicode)
-        self.assertIsInstance(IKSlideshowStartPaused, unicode)
-        self.assertIsInstance(IKSlideshowStartIndex, unicode)
-        self.assertIsInstance(IKSlideshowPDFDisplayBox, unicode)
-        self.assertIsInstance(IKSlideshowPDFDisplayMode, unicode)
-        self.assertIsInstance(IKSlideshowPDFDisplaysAsBook, unicode)
-        self.assertIsInstance(IK_iPhotoBundleIdentifier, unicode)
+        self.assertIsInstance(Quartz.IKSlideshowModeImages, str)
+        self.assertIsInstance(Quartz.IKSlideshowModePDF, str)
+        self.assertIsInstance(Quartz.IKSlideshowModeOther, str)
+        self.assertIsInstance(Quartz.IKSlideshowWrapAround, str)
+        self.assertIsInstance(Quartz.IKSlideshowStartPaused, str)
+        self.assertIsInstance(Quartz.IKSlideshowStartIndex, str)
+        self.assertIsInstance(Quartz.IKSlideshowPDFDisplayBox, str)
+        self.assertIsInstance(Quartz.IKSlideshowPDFDisplayMode, str)
+        self.assertIsInstance(Quartz.IKSlideshowPDFDisplaysAsBook, str)
+        self.assertIsInstance(Quartz.IK_iPhotoBundleIdentifier, str)
 
     @min_os_level("10.6")
     def testConstants10_6(self):
-        self.assertIsInstance(IKSlideshowScreen, unicode)
-        self.assertIsInstance(IKSlideshowAudioFile, unicode)
-        self.assertIsInstance(IKSlideshowPDFDisplayBox, unicode)
-        self.assertIsInstance(IKSlideshowPDFDisplayMode, unicode)
-        self.assertIsInstance(IKSlideshowPDFDisplaysAsBook, unicode)
-        self.assertIsInstance(IK_ApertureBundleIdentifier, unicode)
-        self.assertIsInstance(IK_MailBundleIdentifier, unicode)
+        self.assertIsInstance(Quartz.IKSlideshowScreen, str)
+        self.assertIsInstance(Quartz.IKSlideshowAudioFile, str)
+        self.assertIsInstance(Quartz.IKSlideshowPDFDisplayBox, str)
+        self.assertIsInstance(Quartz.IKSlideshowPDFDisplayMode, str)
+        self.assertIsInstance(Quartz.IKSlideshowPDFDisplaysAsBook, str)
+        self.assertIsInstance(Quartz.IK_ApertureBundleIdentifier, str)
+        self.assertIsInstance(Quartz.IK_MailBundleIdentifier, str)
 
     @min_os_level("10.10")
     def testConstants10_10(self):
-        self.assertIsInstance(IK_PhotosBundleIdentifier, unicode)
-
-
-if __name__ == "__main__":
-    main()
+        self.assertIsInstance(Quartz.IK_PhotosBundleIdentifier, str)
